macro_rules! from_direct {
($source:ident, $target:ident) => { ... };
}Expand description
Convert between two certum variants by directly replacing bits
macro_rules! from_direct {
($source:ident, $target:ident) => { ... };
}Convert between two certum variants by directly replacing bits